// Copyright (c) 2022 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "dawnlibs.hpp"

namespace Dawn {
  class DawnGame;

  class RenderManager {
    public:
      std::weak_ptr<DawnGame> game;

      /**
       * Construct a new RenderManager for a game instance.
       * 
       * @param game Game instance this render manager belongs to.
       */
      RenderManager(std::weak_ptr<DawnGame> game);

      /**
       * Initialize this render manager.
       */
      void init();

      /**
       * Perform a synchronous frame update on the render manager.
       */
      void update();

      /**
       * Destroy a previously initialized RenderManager.
       */
      ~RenderManager();
  };
}